==> v8.3.zip: ru_twords_ru_tw/bible/other/oppress.md <==
# угнетать, угнетение, угнетённый

## Определение:

Слова “угнетать” и “угнетение” означают “жёсткое обращение с людьми”. Угнетатель — это человек, жёстко относящийся к людям. Синонимами слова “угнетать” являются: “притеснять”, “подавлять”, “мучить”.

* Угнетение — это бесчеловечное отношение, эксплуатация, тирания, деспотизм.
* Угнетённый — это человек или народ, подвергающийся жестокому обращению.
* Иноземные цари и их армии жестоко угнетали народ Израиля.

## Варианты перевода:

* В зависимости от контекста глагол “угнетать” можно перевести как “обращаться жестоко”, “мучить”, “порабощать”, “отягощать”, “эксплуатировать”.
* Существительное “угнетение” можно заменить словами “рабство”, “контроль”, “бремя”, “жестокое отношение”.
* Слово “угнетённый” можно перевести как “раб”, “пленник”, “подвергающийся жестокому обращению”.
* Слово “угнетатель” можно перевести как “тиран”, “деспот”, “эксплуататор”, “гонитель”, “мучитель”, “притеснитель”.

(См. также: [связывать](../kt/bond.md), [порабощать](../other/enslave.md), [гнать](../other/persecute.md))

## Ссылки на библейский текст:

* [1 Цар. 10:17-19](rc://*/tn/help/1sa/10/17)
* [Втор. 26:6-7](rc://*/tn/help/deu/26/06)
* [Еккл. 4:1](rc://*/tn/help/ecc/04/01)
* [Иов 10:1-3](rc://*/tn/help/job/10/01)
* [Judges 2:18-19](rc://*/tn/help/jdg/02/18)
* [Неем. 5:14-15](rc://*/tn/help/neh/05/14)
* [Пс. 119:133-134](rc://*/tn/help/psa/119/133)

## Данные о слове:

* Номера Стронга: H1790, H1792, H2541, H2555, H3238, H3905, H3906, H4642, H4939, H5065, H6115, H6125, H6184, H6206, H6216, H6217, H6231, H6233, H6234, H6693, H7429, H7533, H7701, G2616, G2669

==> v9.2.zip: ru_twords_ru_tw/bible/other/oppress.md <==
# угнетать, угнетение, угнетённый, скорбящий

## Определение:

Слова “угнетать” и “угнетение” означают “жёсткое обращение с людьми”. Угнетатель — это человек, жёстко относящийся к людям. Синонимами слова “угнетать” являются: “притеснять”, “подавлять”, “мучить”.

*   Угнетение — это бесчеловечное отношение, эксплуатация, тирания, деспотизм.
*   Угнетённый — это человек или народ, подвергающийся жестокому обращению.
*   Иноземные цари и их армии жестоко угнетали народ Израиля.

## Варианты перевода:

* В зависимости от контекста глагол “угнетать” можно перевести как “обращаться жестоко”, “мучить”, “порабощать”, “отягощать”, “эксплуатировать”. 
* Существительное “угнетение” можно заменить словами “рабство”, “контроль”, “бремя”, “жестокое отношение”. 
* Слово “угнетённый” можно перевести как “раб”, “пленник”, “подвергающийся жестокому обращению”.
* Слово “угнетатель” можно перевести как “тиран”, “деспот”, “эксплуататор”, “гонитель”, “мучитель”, “притеснитель”. 

(См. также: [связывать](../kt/bond.md), [порабощать](../other/enslave.md), [гнать](../other/persecute.md))

## Ссылки на библейский текст:

* [1 Цар. 10:17-19](rc://ru/tn/help/1sa/10/17)
* [Втор. 26:6-7](rc://ru/tn/help/deu/26/06)
* [Еккл. 4:1](rc://ru/tn/help/ecc/04/01)
* [Иов 10:1-3](rc://ru/tn/help/job/10/01)
* [Judges 2:18-19](rc://ru/tn/help/jdg/02/18)
* [Неем. 5:14-15](rc://ru/tn/help/neh/05/14)
* [Пс. 119:133-134](rc://ru/tn/help/psa/119/133)

## Данные о слове:

* Номера Стронга: H1790, H1792, H2541, H2555, H3238, H3905, H3906, H4642, H4939, H5065, H6115, H6125, H6184, H6206, H6216, H6217, H6231, H6233, H6234, H6693, H7429, H7533, H7701, G2616, G2669
